@@ -8,9 +8,9 @@ This package provides tools for:
 - Results visualization and analysis
 """
 
-__version__ = "0.1.1"
-__author__ = "Your Name"
-__email__ = "your.email@example.com"
+__version__ = "0.1.4"
+__author__ = "Peiyang Huo"
+__email__ = "peiyang.huo@kuleuven.be"
 
 # Import main classes for easy access
 from .preprocessing import TaxonomyProcessor
