@@ -20,28 +20,92 @@ from typing import List, Dict, Optional
 class SankeyDataProcessor:
     """
     A class for processing LDA results into Sankey diagram data.
-    
-    This class handles:
-    - Loading and categorizing sample-MC data
-    - Calculating flows between consecutive K values
-    - Integrating MALLET diagnostics and perplexity data
-    - Saving processed data to a JSON file
+
+    This class integrates with LDATrainer to automatically load and process:
+    - Sample-MC probability data
+    - MALLET diagnostic data
+    - Perplexity metrics
+    - Flow calculations between different K values
     """
 
-    def __init__(self, sample_mc_folder: str, mc_feature_folder: str, k_range: List[int], 
-                 high_threshold: float = 0.67, medium_threshold: float = 0.33):
-        self.sample_mc_folder = sample_mc_folder
-        self.mc_feature_folder = mc_feature_folder
-        self.k_range = k_range
+    def __init__(self, base_directory: str, MC_range: List[int], 
+                 high_threshold: float = 0.67, medium_threshold: float = 0.33,
+                 range_str: Optional[str] = None):
+        """
+        Initialize the Sankey Data Processor.
+
+        Args:
+            base_directory: Base directory where LDATrainer saved results
+            MC_range: List of K values (number of topics) to process
+            high_threshold: Threshold for high representation (default 0.67)
+            medium_threshold: Threshold for medium representation (default 0.33)
+            range_str: String representation of range for file naming
+        """
+        self.base_directory = base_directory
+        self.MC_range = MC_range
         self.high_threshold = high_threshold
         self.medium_threshold = medium_threshold
 
-    def load_sample_mc_data(self) -e Dict[int, pd.DataFrame]:
-        """Load all sample-MC probability files."""
+        if range_str is None:
+            self.range_str = f"{min(MC_range)}-{max(MC_range)}"
+        else:
+            self.range_str = range_str
+
+        # Set up paths automatically based on base_directory
+        self._setup_paths()
+
+        print(f"SankeyDataProcessor initialized:")
+        print(f"  Base directory: {self.base_directory}")
+        print(f"  K range: {self.MC_range}")
+        print(f"  Thresholds: High={self.high_threshold}, Medium={self.medium_threshold}")
+
+    def _setup_paths(self):
+        """Set up all necessary paths based on base directory."""
+        self.sample_mc_folder = os.path.join(self.base_directory, 'lda_results', 'MC_Sample')
+        self.mc_feature_folder = os.path.join(self.base_directory, 'lda_results', 'MC_Feature')
+        self.mallet_folder = os.path.join(self.base_directory, 'lda_results', 'Diagnostics')
+        self.perplexity_path = os.path.join(
+            self.base_directory, 'lda_results', f'all_MC_metrics_{self.range_str}.csv'
+        )
+
+        print(f"  Sample MC folder: {self.sample_mc_folder}")
+        print(f"  MC feature folder: {self.mc_feature_folder}")
+        print(f"  MALLET diagnostics: {self.mallet_folder}")
+        print(f"  Perplexity file: {self.perplexity_path}")
+
+    @classmethod
+    def from_lda_trainer(cls, lda_trainer, high_threshold: float = 0.67, 
+                        medium_threshold: float = 0.33):
+        """
+        Create SankeyDataProcessor from an LDATrainer instance.
+
+        Args:
+            lda_trainer: LDATrainer instance that has completed training
+            high_threshold: Threshold for high representation
+            medium_threshold: Threshold for medium representation
+
+        Returns:
+            SankeyDataProcessor instance
+        """
+        if not hasattr(lda_trainer, 'all_metrics') or lda_trainer.all_metrics.empty:
+            raise ValueError("LDATrainer must have completed training before creating SankeyDataProcessor")
+
+        # Get MC_range from the trainer's results
+        MC_range = sorted(lda_trainer.all_metrics['Num_MCs'].unique().astype(int).tolist())
+
+        return cls(
+            base_directory=lda_trainer.base_directory,
+            MC_range=MC_range,
+            high_threshold=high_threshold,
+            medium_threshold=medium_threshold
+        )
+
+    def load_sample_mc_data(self):
+        """Load all sample-MC probability files"""
         sample_mc_data = {}
 
-        for k in self.k_range:
-            filename = f'MC_Sample_Probabilities{k}.csv'
+        for k in self.MC_range:
+            filename = f'MC_Sample_probabilities{k}.csv'
             filepath = os.path.join(self.sample_mc_folder, filename)
 
             if os.path.exists(filepath):
@@ -56,8 +120,8 @@ class SankeyDataProcessor:
 
         return sample_mc_data
 
-    def categorize_sample_assignments(self, sample_mc_data: Dict[int, pd.DataFrame]) -e Dict[int, Dict[str, Dict]]:
-        """Categorize samples into high/medium representation levels."""
+    def categorize_sample_assignments(self, sample_mc_data):
+        """Categorize samples into high/medium representation levels"""
         categorized_data = {}
 
         for k, df in sample_mc_data.items():
@@ -76,10 +140,10 @@ class SankeyDataProcessor:
                 total_prob = 0
 
                 for sample_name, prob in topic_probs.items():
-                    if prob e= self.high_threshold:
+                    if prob >= self.high_threshold:
                         high_samples.append((sample_name, prob))
                         total_prob += prob
-                    elif prob e= self.medium_threshold:
+                    elif prob >= self.medium_threshold:
                         medium_samples.append((sample_name, prob))
                         total_prob += prob
 
@@ -99,10 +163,10 @@ class SankeyDataProcessor:
                 assignment_level = None
 
                 for topic_idx, prob in enumerate(sample_column):
-                    if prob e= self.medium_threshold and prob e max_prob:
+                    if prob >= self.medium_threshold and prob > max_prob:
                         max_prob = prob
                         assigned_topic = f"K{k}_MC{topic_idx}"
-                        assignment_level = 'high' if prob e= self.high_threshold else 'medium'
+                        assignment_level = 'high' if prob >= self.high_threshold else 'medium'
 
                 if assigned_topic:
                     k_data['sample_assignments'][sample_name] = {
@@ -116,8 +180,8 @@ class SankeyDataProcessor:
 
         return categorized_data
 
-    def calculate_flows(self, categorized_data: Dict[int, Dict[str, Dict]]) -e List[Dict]:
-        """Calculate flows between consecutive K values."""
+    def calculate_flows(self, categorized_data):
+        """Calculate flows between consecutive K values"""
         flows = []
         k_values = sorted(categorized_data.keys())
 
@@ -131,7 +195,7 @@ class SankeyDataProcessor:
             flow_counts = defaultdict(lambda: defaultdict(int))
             flow_samples = defaultdict(lambda: defaultdict(list))
 
-            common_samples = set(source_assignments.keys())  set(target_assignments.keys())
+            common_samples = set(source_assignments.keys()) & set(target_assignments.keys())
             print(f"K{source_k}→K{target_k}: {len(common_samples)} samples to track")
 
             for sample in common_samples:
@@ -150,7 +214,7 @@ class SankeyDataProcessor:
 
             for source_segment, targets in flow_counts.items():
                 for target_segment, count in targets.items():
-                    if count e 0:
+                    if count > 0:
                         avg_prob = np.mean([
                             (s['source_prob'] + s['target_prob']) / 2 
                             for s in flow_samples[source_segment][target_segment]
@@ -169,8 +233,8 @@ class SankeyDataProcessor:
         print(f"Total flows calculated: {len(flows)}")
         return flows
 
-    def extract_topic_coherence(self, xml_file_path: str) -e pd.DataFrame:
-        """Extract topic coherence data from a single MALLET diagnostic XML file."""
+    def extract_topic_coherence(self, xml_file_path):
+        """Extract topic coherence data from a single MALLET diagnostic XML file"""
         try:
             tree = ET.parse(xml_file_path)
             root = tree.getroot()
@@ -209,13 +273,13 @@ class SankeyDataProcessor:
             print(f"❌ Unexpected error processing {xml_file_path}: {e}")
             return pd.DataFrame()
 
-    def load_all_mallet_diagnostics(self, mallet_folder_path: str) -e pd.DataFrame:
-        """Load all MALLET diagnostic files."""
-        pattern = os.path.join(mallet_folder_path, 'mallet.diagnostics.*.xml')
+    def load_all_mallet_diagnostics(self):
+        """Load all MALLET diagnostic files"""
+        pattern = os.path.join(self.mallet_folder, 'mallet.diagnostics.*.xml')
         xml_files = glob.glob(pattern)
 
         if not xml_files:
-            print(f"❌ No MALLET diagnostic files found in {mallet_folder_path}")
+            print(f"❌ No MALLET diagnostic files found in {self.mallet_folder}")
             return pd.DataFrame()
 
         print(f"Found {len(xml_files)} MALLET diagnostic files")
@@ -250,10 +314,10 @@ class SankeyDataProcessor:
         print(f"✅ Combined MALLET diagnostics: {len(combined_df)} topics")
         return combined_df
 
-    def load_perplexity_data(self, csv_file_path: str) -e Dict[int, float]:
-        """Load perplexity data from CSV file."""
+    def load_perplexity_data(self):
+        """Load perplexity data from CSV file"""
         try:
-            df = pd.read_csv(csv_file_path)
+            df = pd.read_csv(self.perplexity_path)
             df = df.loc[:, ~df.columns.str.contains('^Unnamed')]
 
             if 'Num_MCs' not in df.columns or 'Perplexity' not in df.columns:
@@ -273,8 +337,8 @@ class SankeyDataProcessor:
             print(f"❌ Error loading perplexity data: {e}")
             return {}
 
-    def save_processed_data(self, sankey_data: Dict, output_path: str = 'sankey_data.json'):
-        """Save processed data to JSON file."""
+    def save_processed_data(self, sankey_data, output_filename='sankey_data.json'):
+        """Save processed data to JSON file"""
         if sankey_data is None:
             print("❌ No data to save")
             return
@@ -298,13 +362,16 @@ class SankeyDataProcessor:
 
         converted_data = deep_convert(sankey_data)
 
+        # Save to the LDA results directory
+        output_path = os.path.join(self.base_directory, 'lda_results', output_filename)
+
         with open(output_path, 'w') as f:
             json.dump(converted_data, f, indent=2)
 
         print(f"💾 Data saved to {output_path}")
+        return output_path
 
-    def process_all_data(self, mallet_folder_path: str, perplexity_csv_path: str, 
-                         output_path: str = 'fully_integrated_sankey_data.json') -e Optional[Dict]:
+    def process_all_data(self, output_filename='fully_integrated_sankey_data.json'):
         """
         🚀 SINGLE METHOD TO GET FULLY INTEGRATED DATA
 
@@ -361,7 +428,7 @@ class SankeyDataProcessor:
 
         # Step 3: Integrate MALLET diagnostics
         print("\n5️⃣ Integrating MALLET diagnostics...")
-        mallet_df = self.load_all_mallet_diagnostics(mallet_folder_path)
+        mallet_df = self.load_all_mallet_diagnostics()
 
         if not mallet_df.empty:
             mallet_dict = mallet_df.set_index('global_topic_id').to_dict('index')
@@ -396,7 +463,7 @@ class SankeyDataProcessor:
 
         # Step 4: Integrate perplexity data
         print("\n6️⃣ Integrating perplexity data...")
-        perplexity_dict = self.load_perplexity_data(perplexity_csv_path)
+        perplexity_dict = self.load_perplexity_data()
 
         if perplexity_dict:
             integrated_count = 0
@@ -428,7 +495,7 @@ class SankeyDataProcessor:
 
         # Step 5: Save the final result
         print("\n7️⃣ Saving fully integrated data...")
-        self.save_processed_data(sankey_data, output_path)
+        output_path = self.save_processed_data(sankey_data, output_filename)
 
         # Final summary
         print("\n" + "=" * 60)
@@ -449,4 +516,3 @@ class SankeyDataProcessor:
         print("=" * 60)
 
         return sankey_data
-
