@@ -124,7 +124,9 @@ class MCComparison:
         Returns:
             A Series with feature probabilities
         """
-        filepath = os.path.join(self.base_directory, 'lda_results', 'MC_Feature', f'MC_Feature_Probabilities_{mc_id.split('_')[0][1:]}.csv')
+        k_value = mc_id.split('_')[0][1:]  # Extract the K value
+        filepath = os.path.join(self.base_directory, 'lda_results', 'MC_Feature', 
+                       f'MC_Feature_Probabilities_{k_value}.csv')
         mc_feature_df = pd.read_csv(filepath, index_col=0)
         return mc_feature_df.loc[mc_feature_df.index == mc_id].squeeze()
 
@@ -140,7 +142,7 @@ This module contains classes for:
 """
 
 
-from typing import List, Dict, Optional, Tuple, Any
+from typing import List, Dict, Optional, Tuple, Any, Callable
 import os
 import pandas as pd
 import numpy as np
@@ -211,6 +213,7 @@ class LDAModelVisualizer:
         print(f"  Universal headers: {universal_headers}")
         print(f"  Continuous headers: {continuous_headers or 'None'}")
 
+
     def _setup_paths(self):
         """Set up all necessary paths."""
         self.loop_directory = os.path.join(self.base_directory, 'lda_loop')
@@ -225,12 +228,17 @@ class LDAModelVisualizer:
 
         # Set up file paths for this specific K value
         self.path_to_DirichletComponentProbabilities = os.path.join(
-            self.MC_sample_directory, f"MC_Sample_probabilities{self.k_value}.csv"
+            self.MC_sample_directory, 
+            f"MC_Sample_probabilities{self.k_value}.csv"
         )
         self.path_to_ASVProbabilities = os.path.join(
-            self.MC_feature_directory, f"MC_Feature_Probabilities_{self.k_value}.csv"
+            self.MC_feature_directory, 
+            f"MC_Feature_Probabilities_{self.k_value}.csv"
+        )
+        self.path_to_new_taxa = os.path.join(
+            self.inter_directory, 
+            "intermediate_taxa.csv"
         )
-        self.path_to_new_taxa = os.path.join(self.inter_directory, "intermediate_taxa.csv")
 
     def _set_default_colors(self):
         """Set up empty color configurations - will use seaborn/matplotlib defaults."""
